==> nextcloud-15.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/sv.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Uppstartsguiden",
    "Add your profile information! For example your email is needed to reset your password." : "Fyll i dina personliga inställningar! Till exempel behövs din e-postadress för att återställa ditt lösenord.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Fyll i dina personliga inställningar! Välj en profilbild och fyll i ditt namn för att enklare kunna arbeta med samtliga funktioner i molnet.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Fyll i dina personliga inställningar! Fyll i ditt namn för att enklare kunna arbeta med samtliga funktioner i molnet.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Fyll i dina personliga inställningar! Välj en profilbild för att enklare kännas igen bland övriga användare i molnet.",
    "About" : "Om",
    "A welcome and introduction wizard for Nextcloud" : "En välkomst och introduktionsguide för Nextcloud",
    "Extend your cloud" : "Utöka ditt moln",
    "Find more than 100 apps in the Nextcloud app store to customize your cloud:" : "Hitta fler än 100 appar i Nextcloud app store för att anpassa ditt moln:",
    "Groupware apps like Calendar, Contacts, Mail" : "Grupprogram som kalender, kontakter och e-post",
    "Communication with Nextcloud Talk" : "Kommunicera med Nextcloud Talk",
    "Collaboration apps for document editing" : "Samarbetsappar för dokumentredigering",
    "Security and authentication features like two-factor authentication, SSO and ransomware protection" : "Säkerhets- och autentiseringsfunktioner som tvåfaktors autentisering, SSO och ransomware-skydd",
    "Many others like a music player, a password manager, a kanban app, a download manager or a markdown editor" : "Många andra som en musikspelare, en lösenordshanterare, en kanbanapp, en nedladdningshanterare eller en markdownredigerare",
    "Browse the app store" : "Bläddra i app store",
    "Stay in sync" : "Var synkad",
    "Nextcloud gives you access to your files wherever you are." : "Nextcloud ger dig tillgång till dina filer var du än befinner dig.",
    "Our easy to use desktop and mobile clients are available for all major platforms at zero cost!" : "Våra lättanvända skrivbords- och mobilklienter är tillgängliga för alla större plattformar utan kostnad!",
    "Get the apps to sync your files" : "Skaffa apparna för att synkronisera dina filer",
    "Desktop client" : "Skrivbordsklient",
    "Android app" : "Android app",
    "iOS app" : "iOS app",
    "Connect your desktop apps to %s" : "Anslut dina skrivbordsappar till %s",
    "Connect your calendar" : "Anslut din kalender",
    "Connect your contacts" : "Anslut dina kontakter",
    "Access files via WebDAV" : "Åtkomst av filer via WebDAV",
    "Get help" : "Få hjälp",
    "Get more information" : "Skaffa mer information",
    "The Nextcloud documentation for home users:" : "Nextcloud-dokumentation för hemanvändare:",
    "User manual" : "Manual för användare",
    "Admin manual" : "Manual för administratörer",
    "Developer manual" : "Manual för utvecklare",
    "You can also ask for help in our community support channels:" : "Du kan också begära hjälp i våra gemenskapsupportkanaler:",
    "the Nextcloud forums" : "Nextcloud forum",
    "the Nextcloud IRC chat channel on freenode.net" : "Nextcloud IRC chattkanal på freenode.net",
    "Start contributing" : "Börja bidra",
    "Do you want to get a certain improvement in Nextcloud? Did you find a problem? Do you want to help translate, promote or document Nextcloud?" : "Vill du få en viss förbättring i Nextcloud? Hittade du ett problem? Vill du hjälpa till att översätta, marknadsföra eller dokumentera Nextcloud?",
    "Become part of the Community" : "Bli en del av gemenskapen",
    "Enterprise support" : "Enterprise support",
    "If you run Nextcloud in a mission critical environment with large numbers of users and big amounts of data and need the certainty of support from the experts behind the Nextcloud technology, an Enterprise Subscription from Nextcloud is available with email and phone support." : "Om du kör Nextcloud i produktionsmiljö med många användare, mycket data och behöver trygghet med support från experterna bakom Nextcloud-tekniken, finns en Enterprise-prenumeration från Nextcloud med e-post och telefonsupport.",
    "Get enterprise support" : "Skaffa enterprise support",
    "A safe home for all your data" : "Ett säkert hem för dina filer",
    "Nextcloud puts your data at your fingertips, under your control. Store your documents, calendar, contacts and photos on a server in your company, at home, at one of our providers or in a data center you know." : "Nextcloud ger dig full kontroll över din data. Spara dina dokument, kalender, kontakter och foton på en server i ditt företag, hemma, hos en av våra leverantörer eller i ett känt datacenter.",
    "Host your data and files where you decide" : "Lagra din data och filer där du vill",
    "Open Standards and Interoperability" : "Öppna standarder och interoperabilitet",
    "100%% Open Source & community-focused" : "100%% öppen källkod & gemenskapfokuserad",
    "Learn more about %s" : "Lär mer om %s",
    "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "%s ger dig tillgång till dina filer var du än befinner dig. Våra lättanvända skrivbords- och mobilklienter är tillgängliga för alla större plattformar utan kostnad.",
    "Setup sync clients using an <a href=\"%s\">app password</a>. That way you can make sure you are able to revoke access in case you lose that device." : "Konfigurera synk-klienter att använda ett <a href=\"%s\">app-lösenord</a>. På det sättet kan du återkalla åtkomst om du förlorar enheten.",
    "Connect other apps to %s" : "Anslut andra appar till %s",
    "Besides the sync clients you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to %s." : "Förutom synkroniseringsklienterna kan du ansluta någon annan programvara som stöder WebDAV/CalDAV/CardDAV-protokollen till %s.",
    "Previous" : "Föregående",
    "Next" : "Nästa",
    "Start using Nextcloud" : "Börja använda Nextcloud",
    "If you want to support the project {contributeopen}join development{linkclose} or {contributeopen}spread the word{linkclose}!" : "Om du vill stödja projektet {contributeopen}gå med i utveckling{linkclose} eller {contributeopen}sprida information{linkclose}!",
    "Show First Run Wizard again" : "Visa introduktionsguiden igen",
    "Access & share your files, calendars, contacts, mail & more from any device, on your terms" : "Din personliga webbtjänst. Synka & dela dina filer, kalender, kontakter, mail och ännu mer från vilken enhet som helst, på dina villkor",
    "There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"%s\">website</a>." : "Det finns mer information i <a target=\"_blank\" href=\"%s\">dokumentationen</a> och på vår <a target=\"_blank\" href=\"%s\">webbsida</a>.",
    "If you like Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\"> recommend it to your friends</a> and <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribute back</a>!" : "Om du gillar Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud är en jättebra mjukvara för att synkronisera och dela dina filer. Du kan hämta det gratis från https://nextcloud.com\"> rekommendera det till dina vänner och kollegor</a> och <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">hjälp oss att bli ännu bättre</a>!"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/sv.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Uppstartsguiden",
    "Add your profile information! For example your email is needed to reset your password." : "Fyll i dina personliga inställningar! Till exempel behövs din e-postadress för att återställa ditt lösenord.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Fyll i dina personliga inställningar! Välj en profilbild och fyll i ditt namn för att enklare kunna arbeta med samtliga funktioner i molnet.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Fyll i dina personliga inställningar! Fyll i ditt namn för att enklare kunna arbeta med samtliga funktioner i molnet.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Fyll i dina personliga inställningar! Välj en profilbild för att enklare kännas igen bland övriga användare i molnet.",
    "About" : "Om",
    "A welcome and introduction wizard for Nextcloud" : "En välkomst och introduktionsguide för Nextcloud",
    "Previous" : "Föregående",
    "Next" : "Nästa",
    "Close" : "Stäng",
    "Start using Nextcloud" : "Börja använda Nextcloud",
    "Extend your cloud" : "Utöka ditt moln",
    "Find more than 100 apps in the Nextcloud app store to customize your cloud:" : "Hitta fler än 100 appar i Nextcloud app store för att anpassa ditt moln:",
    "Groupware apps like Calendar, Contacts, Mail" : "Grupprogram som kalender, kontakter och e-post",
    "Communication with Nextcloud Talk" : "Kommunicera med Nextcloud Talk",
    "Collaboration apps for document editing" : "Samarbetsappar för dokumentredigering",
    "Security and authentication features like two-factor authentication, SSO and ransomware protection" : "Säkerhets- och autentiseringsfunktioner som tvåfaktors autentisering, SSO och ransomware-skydd",
    "Many others like a music player, a password manager, a kanban app, a download manager or a markdown editor" : "Många andra som en musikspelare, en lösenordshanterare, en kanbanapp, en nedladdningshanterare eller en markdownredigerare",
    "Browse the app store" : "Bläddra i app store",
    "Stay in sync" : "Var synkad",
    "Nextcloud gives you access to your files wherever you are." : "Nextcloud ger dig tillgång till dina filer var du än befinner dig.",
    "Our easy to use desktop and mobile clients are available for all major platforms at zero cost!" : "Våra lättanvända skrivbords- och mobilklienter är tillgängliga för alla större plattformar utan kostnad!",
    "Get the apps to sync your files" : "Skaffa apparna för att synkronisera dina filer",
    "Desktop client" : "Skrivbordsklient",
    "Android app" : "Android app",
    "iOS app" : "iOS app",
    "Connect your desktop apps to %s" : "Anslut dina skrivbordsappar till %s",
    "Connect your calendar" : "Anslut din kalender",
    "Connect your contacts" : "Anslut dina kontakter",
    "Access files via WebDAV" : "Åtkomst av filer via WebDAV",
    "Download macOS/iOS configuration profile" : "Hämta macOS/iOS konfigurationsprofil",
    "Get help" : "Få hjälp",
    "Get more information" : "Skaffa mer information",
    "The Nextcloud documentation for home users:" : "Nextcloud-dokumentation för hemanvändare:",
    "User manual" : "Manual för användare",
    "Admin manual" : "Manual för administratörer",
    "Developer manual" : "Manual för utvecklare",
    "You can also ask for help in our community support channels:" : "Du kan också begära hjälp i våra gemenskapsupportkanaler:",
    "the Nextcloud forums" : "Nextcloud forum",
    "the Nextcloud IRC chat channel on freenode.net" : "Nextcloud IRC chattkanal på freenode.net",
    "Start contributing" : "Börja bidra",
    "Do you want to get a certain improvement in Nextcloud? Did you find a problem? Do you want to help translate, promote or document Nextcloud?" : "Vill du få en viss förbättring i Nextcloud? Hittade du ett problem? Vill du hjälpa till att översätta, marknadsföra eller dokumentera Nextcloud?",
    "Become part of the Community" : "Bli en del av gemenskapen",
    "Enterprise support" : "Enterprise support",
    "If you run Nextcloud in a mission critical environment with large numbers of users and big amounts of data and need the certainty of support from the experts behind the Nextcloud technology, an Enterprise Subscription from Nextcloud is available with email and phone support." : "Om du kör Nextcloud i produktionsmiljö med många användare, mycket data och behöver trygghet med support från experterna bakom Nextcloud-tekniken, finns en Enterprise-prenumeration från Nextcloud med e-post och telefonsupport.",
    "Get enterprise support" : "Skaffa enterprise support",
    "A safe home for all your data" : "Ett säkert hem för dina filer",
    "Nextcloud puts your data at your fingertips, under your control. Store your documents, calendar, contacts and photos on a server in your company, at home, at one of our providers or in a data center you know." : "Nextcloud ger dig full kontroll över din data. Spara dina dokument, kalender, kontakter och foton på en server i ditt företag, hemma, hos en av våra leverantörer eller i ett känt datacenter.",
    "Host your data and files where you decide" : "Lagra din data och filer där du vill",
    "Open Standards and Interoperability" : "Öppna standarder och interoperabilitet",
    "100%% Open Source & community-focused" : "100%% öppen källkod & gemenskapfokuserad",
    "Learn more about %s" : "Lär mer om %s",
    "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "%s ger dig tillgång till dina filer var du än befinner dig. Våra lättanvända skrivbords- och mobilklienter är tillgängliga för alla större plattformar utan kostnad.",
    "Setup sync clients using an <a href=\"%s\">app password</a>. That way you can make sure you are able to revoke access in case you lose that device." : "Konfigurera synk-klienter att använda ett <a href=\"%s\">app-lösenord</a>. På det sättet kan du återkalla åtkomst om du förlorar enheten.",
    "Connect other apps to %s" : "Anslut andra appar till %s",
    "Besides the sync clients you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to %s." : "Förutom synkroniseringsklienterna kan du ansluta någon annan programvara som stöder WebDAV/CalDAV/CardDAV-protokollen till %s.",
    "If you want to support the project {contributeopen}join development{linkclose} or {contributeopen}spread the word{linkclose}!" : "Om du vill stödja projektet {contributeopen}gå med i utveckling{linkclose} eller {contributeopen}sprida information{linkclose}!",
    "Show First Run Wizard again" : "Visa introduktionsguiden igen",
    "Access & share your files, calendars, contacts, mail & more from any device, on your terms" : "Din personliga webbtjänst. Synka & dela dina filer, kalender, kontakter, e-post och ännu mer från vilken enhet som helst, på dina villkor",
    "There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"%s\">website</a>." : "Det finns mer information i <a target=\"_blank\" href=\"%s\">dokumentationen</a> och på vår <a target=\"_blank\" href=\"%s\">webbsida</a>.",
    "If you like Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\"> recommend it to your friends</a> and <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribute back</a>!" : "Om du gillar Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud är en jättebra mjukvara för att synkronisera och dela dina filer. Du kan hämta det gratis från https://nextcloud.com\"> rekommendera det till dina vänner och kollegor</a> och <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">hjälp oss att bli ännu bättre</a>!"
},
"nplurals=2; plural=(n != 1);");
